![figure](docs/source/resource/image/splash.png)

# ![icon](docs/source/resource/icon/icon_pixel.png) Welcome to the Platform!

[![Discord Chat](https://img.shields.io/discord/657211973435392011.svg)](https://discord.gg/BkMmFUC)
<a href="https://twitter.com/jsuarez5341?ref_src=twsrc%5Etfw" target="_blank">
  <img src="http://jpillora.com/github-twitter-button/img/tweet.png"
       alt="tweet button" title="Follow"></img>
</a>

Neural MMO is a massively multiagent environment for artificial intelligence research inspired by Massively Multiplayer Online (MMO) role-playing games. The project is under active development with major updates every 3-6 months. This README is a stub -- all of our [Documentation](https://jsuarez5341.github.io "Neural MMO Documentation") is hosted by github.io.

[![Demo Video](http://img.youtube.com/vi/d1mj8yzjr-w/0.jpg)](http://www.youtube.com/watch?v=d1mj8yzjr-w "Neural MMO v1.5 Demo")
